.. Copyright 2014-2018 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Preparing for installation on Windows
=====================================


1. Python and basic development tools

   Install Python as per the instructions on `The Hitchhiker's guide to Python
   <http://python-guide.readthedocs.io/en/latest/starting/install3/win/>`_.

   Super-short summary:

     - Download and install `Chocolatey <https://chocolatey.org/install>`_.
     - Install Python: :code:`choco install python`.


2. Wheel support and virtualenv

   - Ensure you have the latest pip with wheel support

     .. code-block:: bash
    
       python -m pip install -U pip

   - Install virtualenv using wheels:

     In a command prompt window, execute:

     .. code-block:: bash

        pip install -U virtualenv


Next, :ref:`create a virtualenv <install-reahl-itself>`.
